==> nateon-1.0.1.192.tar.bz2: nateon-1.0/nateon/dialog/webwindow.h <==
/***************************************************************************
 *   Copyright (C) 2008 by SK Communications.                              *
 *   http://kldp.net/projects/nateon/                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef WEBFORM1_H
#define WEBFORM1_H

#include <qvariant.h>
#include <qdialog.h>
#include <kstandarddirs.h>
#include <kaboutdata.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;

class WebForm1 : public QWidget
{
Q_OBJECT

public:
    WebForm1( QWidget* parent = 0, const char* name = 0 );
    ~WebForm1();


protected:

protected slots:
    virtual void languageChange();

};

#endif // WEBFORM1_H

==> nateon-1.0.1.275.tar.bz2: nateon-1.0/nateon/dialog/webwindow.h <==
/***************************************************************************
 *   Copyright (C) 2008 by SK Communications.                              *
 *   http://kldp.net/projects/nateon/                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef WEBFORM1_H
#define WEBFORM1_H

#include <qvariant.h>
#include <qdialog.h>
#include <kstandarddirs.h>
#include <kaboutdata.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;

class WebForm1 : public QWidget {
    Q_OBJECT

public:
    WebForm1( QWidget* parent = 0, const char* name = 0 );
    ~WebForm1();


protected:

protected slots:
    virtual void languageChange();

};

#endif // WEBFORM1_H
